/*
 * Copyright (C) 2021-2024  CZ.NIC, z. s. p. o.
 *
 * This file is part of FRED.
 *
 * FRED is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * FRED is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with FRED.  If not, see <https://www.gnu.org/licenses/>.
 */

#include "src/keyset.hh"

#include <tuple>

namespace {

decltype(auto) to_tuple(const Fred::Akm::Dnskey& dnskey)
{
    return std::make_tuple(dnskey.public_key, dnskey.flags, dnskey.proto, dnskey.alg);
}

}//namespace {anonymous}

bool Fred::Akm::operator<(const Dnskey& lhs, const Dnskey& rhs)
{
    return to_tuple(lhs) < to_tuple(rhs);
}

bool Fred::Akm::operator==(const Dnskey& lhs, const Dnskey& rhs)
{
    return to_tuple(lhs) == to_tuple(rhs);
}

std::string Fred::Akm::to_string(const Dnskey& dnskey)
{
    return "["
            "flags: " + std::to_string(*dnskey.flags) + ", "
            "protocol: " + std::to_string(*dnskey.proto) + ", "
            "algorithm: " + std::to_string(*dnskey.alg) + ", "
            "key: \"" + *dnskey.public_key + "\""
           "]";
}
